@@ -559,7 +559,7 @@ class FlickrUserPhotostreamMirroringAgent:
             # TYPE SAVE: [Index, Page]
             "FIFO": [int(photo_count) - ((int(page_count) - 1) * 100) + 1, page_count],
             "LIFO": [0, 1],
-            "new_photos": None,
+            "new_photos": [],
             "number_of_new_photos": 0,
             "new_photo_pages": []  # list of pages have new photos
         }
@@ -572,32 +572,33 @@ class FlickrUserPhotostreamMirroringAgent:
                 self.__cache = json.load(json_file)
 
             # check if new photo
-            while True:
-                self.__get_photo_info(photos[i])
-                # if downloaded
-                if os.path.isfile(photos[i]._info[1]):
-                    break
-                # count
-                index += 1
-                if index > 99:
-                    index = 0
-                    page += 1
-                    photos = self.__API.get_photos(self.user.id, page, 100)[0]
+            if self.__cache["LIFO"] != [0, 1]:
+                while True:
+                    self.__get_photo_info(photos[index])
+                    # if downloaded
+                    if os.path.isfile(photos[index]._info[1]):
+                        break
+                    # count
+                    index += 1
+                    if index > 99:
+                        index = 0
+                        page += 1
+                        photos = self.__API.get_photos(self.user.id, page, 100)[0]
 
-            self.__cache["number_of_new_photos"] += index + (page - 1)*100
+                self.__cache["number_of_new_photos"] += index + (page - 1)*100
 
-            if self.__cache["number_of_new_photos"] > 0:
-                # have new_photo not downloaded yet
-                if self.__cache["new_photo_pages"]:
-                    pages_move = (
-                        self.__cache["new_photos"] + self.__cache["number_of_new_photos"])//100
-                    if pages_move > 0:
-                        for i in range(len(self.__cache["new_photo_pages"])):
-                            self.__cache["new_photo_pages"][i] += pages_move
+                if self.__cache["number_of_new_photos"] > 0:
+                    # have new_photo not downloaded yet
+                    if self.__cache["new_photo_pages"]:
+                        pages_move = (
+                            self.__cache["new_photos"] + self.__cache["number_of_new_photos"])//100
+                        if pages_move > 0:
+                            for i in range(len(self.__cache["new_photo_pages"])):
+                                self.__cache["new_photo_pages"][i] += pages_move
 
-                self.__cache["new_photos"] = [index, page]
-                for i in range(page):
-                    self.__cache["new_photo_pages"].append(i + 1)
+                    self.__cache["new_photos"] = [index, page]
+                    for i in range(page):
+                        self.__cache["new_photo_pages"].append(i + 1)
         else:
             self.__cache = cache_data
 
